﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2010 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;
using HeuristicLab.Common;

namespace HeuristicLab.Clients.Hive {

  public partial class Job : IDeepCloneable {

    public Job() { }

    public void SetState(JobState state) {
      this.State = state;
      this.StateLog.Add(new StateLog() { State = state, DateTime = DateTime.Now });
    }

    public void SetState(JobState state, Guid userId) {
      this.State = state;
      this.StateLog.Add(new StateLog() { State = state, DateTime = DateTime.Now, UserId = userId });
    }

    public void SetState(JobState state, Guid slaveId, string exception) {
      this.State = state;
      this.StateLog.Add(new StateLog() { State = state, DateTime = DateTime.Now, SlaveId = slaveId, Exception = exception });
    }

    protected Job(Job original, Cloner cloner) {
      this.Priority = original.Priority;
      this.CoresNeeded = original.CoresNeeded;
      this.MemoryNeeded = original.MemoryNeeded;
      this.PluginsNeededIds = new List<Guid>(original.PluginsNeededIds);
      this.LastHeartbeat = original.LastHeartbeat;
      this.IsParentJob = original.IsParentJob;
      this.FinishWhenChildJobsFinished = original.FinishWhenChildJobsFinished;
      this.ExecutionTime = original.ExecutionTime;
      this.ParentJobId = original.ParentJobId;
      this.StateLog = new List<StateLog>(original.StateLog);
      this.State = original.State;
      this.Id = original.Id;
    }

    public IDeepCloneable Clone(Cloner cloner) {
      return new Job(this, cloner);
    }

    public object Clone() {
      return Clone(new Cloner());
    }
  }
}
