﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2010 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;
using System.Linq;

namespace HeuristicLab.Clients.Hive {

  public partial class LightweightJob {

    public LightweightJob() {
      StateLog = new List<StateLog>();
    }


    public LightweightJob(Job job) {
      this.Id = job.Id;
      this.ExecutionTime = job.ExecutionTime;
      this.ParentJobId = job.ParentJobId;
      this.StateLog = new List<StateLog>(job.StateLog);
      this.State = job.State;
    }

    public StateLog CurrentStateLog { get { return StateLog.Last(); } }
    public DateTime DateCreated { get { return StateLog.First().DateTime; } }
    public DateTime? DateFinished { get { return CurrentStateLog.State == JobState.Finished ? new DateTime?(CurrentStateLog.DateTime) : null; } }

    public void SetState(JobState state) {
      this.State = state;
      this.StateLog.Add(new StateLog() { State = state, DateTime = DateTime.Now });
    }

    public void SetState(JobState state, Guid userId) {
      this.State = state;
      this.StateLog.Add(new StateLog() { State = state, DateTime = DateTime.Now, UserId = userId });
    }

    public void SetState(JobState state, Guid slaveId, string exception) {
      this.State = state;
      this.StateLog.Add(new StateLog() { State = state, DateTime = DateTime.Now, SlaveId = slaveId, Exception = exception });
    }
  }
}
